
typelike
========
dummy objects to hold similar types

<nobr><img src="https://img.shields.io/pypi/v/typelike" alt="version"/></nobr>
<nobr><img src="https://img.shields.io/travis/com/lockhartlab/typelike/master"  alt="build-status-master"/></nobr>
<nobr><img src="https://img.shields.io/codecov/c/github/lockhartlab/typelike/master" alt="coverage-master"/></nobr>

<hr>

install simply by calling ```pip install typelike```

